(function($)
{
	var myalbumBrowser = (function(el)
	{
  	var Browser = new function Browser()
  	{
    	this.cache = {};
    	this.query = '';
    	
    	this.init = function()
    	{
      	$(document).ready(function()
      	{
        	this.el = document.getElementById('myalbumContent');
        	this.form = document.getElementById('myalbumForm');
        	this.nav = document.getElementById('myalbum-nav');
        	this.searchEl = document.getElementById('myalbum-search-input');
        	this.spinner = document.getElementById('myalbum-spinner');
        	this.setEvents();
        	
        	this.load();
      	}.bind(this));
    	}
    	
    	this.load = function()
    	{
      	var data = {
        	action: 'myalbum_json',
        	exec: 'content'
      	};
      	
      	$.ajax(
        {
          url: ajax_object.ajax_url,
          type: 'GET',
          dataType: 'json',
          data: data,
          cache: true
        }).done(function(json)
        {
          this.setContent(json.data);
          this.render();
        }.bind(this));
    	}
    	
    	this.startSpinner = function()
    	{
      	$(this.spinner).addClass('is-active');
    	}
    	
    	this.stopSpinner = function()
    	{
      	$(this.spinner).removeClass('is-active');
    	}
    	
    	this.search = function(query)
    	{
      	if(this.searchRequest)
      	  this.searchRequest.abort();
      	  
        if(this.query==query) 
      	  return;

        this.el.innerHTML = '';
      	this.startSpinner();
      	if(query==='')
      	{
        	this.query = '';
          this.render('');
          return;
        }
        
      	this.query = query;
      	var data = {
        	action: 'myalbum_json',
        	exec: 'search',
        	search: query
      	};
      	
      	this.searchRequest = $.ajax(
        {
          url: ajax_object.ajax_url,
          type: 'GET',
          dataType: 'json',
          data: data,
          cache: false
        }).done(function(json)
        {
          this.render(json.data.content, json.data.msg);
        }.bind(this));
    	}
    	
    	this.setContent = function(json)
    	{
      	this.content = json;
      	for(var a=this.nav.length-1; a>=0; a--)
        {
          this.nav.remove(a);
        }
        
        var option = document.createElement('option');
        option.value = '';
        option.text = 'MyAlbum';
        this.nav.add(option);
      	
      	var loopContent = function(content, depth, parent)
      	{
        	for(var a=0; a<content.length; a++)
        	{
          	var item = content[a];
          	this.cache[item.key] = item;
          	
          	if(item.content)
          	{
            	// add to nav select
            	var option = document.createElement('option');
            	option.value = item.key;
            	
            	var prefix = '';
            	for(var b=1; b<depth; b++)
            	  prefix += "&nbsp;&nbsp;&nbsp;&nbsp;";
            	
            	option.innerHTML = prefix+'- '+item.title;
            	this.nav.add(option);
            	item.navOption = option;
            	
            	// Parent
            	if(parent)
          	    item.parent = parent.key;
              else
          	    item.parent = '';
            	
          	  loopContent(item.content, depth+1, item);
          	}
        	}
      	}.bind(this);
      	loopContent(this.content.content, 1);
    	}
    	
    	this.setEvents = function()
    	{
      	var self = this;
      	$(this.el).on('click', '.item', function(e)
      	{
        	self.select(this);
      	});
      	
      	$(this.el).on("keydown", function(e)
        {
          if(e.keyCode==32)
            e.preventDefault();
        });
        
        $(this.el).on("keyup", ".item", function(e)
        {
          var activeEl = document.activeElement;
          if(e.keyCode==32 && jQuery(activeEl).hasClass("item"))
          {
            e.preventDefault();
            e.stopPropagation();
            self.select(activeEl);
          }
        });
        
        $(this.form).on("submit", function(e)
        {
          self.chooseAlbum();
          return false;
        }.bind(this));
        
        $(this.searchEl).on('keyup change search input', function(e)
        {
          if(e.type=='keyup' && e.keyCode!==13 && this.value!='')
            return;
          
          self.search(this.value);
          this.setAttribute('val', this.value);
        });
        
        $(this.nav).on('change', function(e)
        {
          var key = this.options[this.selectedIndex].value;
          if(key=='')
            self.render();
          else
            self.render(key);
        });
    	}
    	
    	this.select = function(el)
    	{
      	$(".item.checked").removeClass("checked");
      	if(!el.hasAttribute('key'))
      	{
      	  document.getElementById('myalbumSubmitBtn').disabled = true;
      	  return;
        }
      	 
        $(el).addClass("checked");
        var type = el.getAttribute('type');
        var key = el.getAttribute('key');
        if(type=='album')
        {
          document.getElementById('myalbumSubmitBtn').disabled = false;
        }else if(type=='folder')
        {
          document.getElementById('myalbumSubmitBtn').disabled = true;
          this.render(key);
        }else if(type=='back')
        {
          document.getElementById('myalbumSubmitBtn').disabled = true;
          this.render(key);
        }
    	}
    	
    	this.chooseAlbum = function()
    	{
      	var selected = $(".myalbum .item.checked");
        if(selected.length>0)
        {
          var key = selected[0].getAttribute("key");
          var win = window.dialogArguments || opener || parent || top;
          win.send_to_editor("[myalbum album=\""+key+"\"]");
        }
    	}
    	
    	this.render = function(key, msg)
    	{
      	this.stopSpinner();
      	
      	var parent = undefined;
      	if(key===undefined || (typeof key ==='string' || key instanceof String))
      	{
        	if(key===undefined || key==='')
          {
            // root
            content = this.content.content;
            this.nav.options[0].selected = true;
          }else
          {
            // folder
            parent = this.cache[key].parent;
            content = this.cache[key].content;
            this.cache[key].navOption.selected = true;
          }
          
          this.searchEl.value = '';
          this.nav.style.display = '';
      	}else
        {
          // render object
          content = key;
          this.nav.style.display = 'none';
          type = 'object';
        }
      	
      	var temp = document.createDocumentFragment();
      	if(parent!==undefined)
      	{
        	var back = document.createElement('li');
        	back.className = 'item';
        	back.setAttribute('type', 'back');
        	back.setAttribute('key', parent);
        	back.setAttribute('tabindex', 1);
        	
        	var preview = document.createElement('div');
        	preview.className = 'preview';
        	back.appendChild(preview);
        	temp.appendChild(back);
      	}
      	
      	for(var a=0; a<content.length; a++)
      	{
        	var el = document.createElement('li');
        	el.className = 'item';
        	el.setAttribute('type', content[a].type);
        	el.setAttribute('title', content[a].title);
        	
        	if(content[a].key)
        	  el.setAttribute('key', content[a].key);
        	
        	if(content[a].key)
        	  el.setAttribute('tabindex', a+2);
        	
        	var preview = document.createElement('div');
        	preview.className = 'preview';
        	var inner = document.createElement('div');
        	preview.appendChild(inner);
        	
        	if(content[a].headerPhoto)
        	{
          	var photo = this.content.domains[content[a].headerPhoto[4]]+content[a].headerPhoto[3];
          	inner.style.backgroundImage = 'url('+photo+')';
        	}
        	
        	el.appendChild(preview);
        	temp.appendChild(el);
      	}
      	
      	if(msg!==undefined)
      	{
        	var msgEl = document.createElement('li');
        	msgEl.className = 'msg';
        	msgEl.innerHTML = msg;
        	temp.appendChild(msgEl);
      	}
      	
      	this.el.innerHTML = '';
      	this.el.appendChild(temp);
    	}
    	
    	this.init();
  	}
  	
  	return {};
	})();	
}(jQuery));