<?php
namespace MyAlbum;
use \WP_REST_Server;

if ( ! defined( 'WPINC' ) ) {
	die;
}

class Blocks
{
  function __construct()
  { 
    if(function_exists('wp_set_script_translations'))
    {
      add_action('rest_api_init', array($this, 'registerRoutes'));
      add_action('admin_enqueue_scripts', array($this, 'enqueueAdminBlockAssets'));
      add_action('wp_enqueue_scripts', array($this, 'enqueueBlockAssets'));  
      if(is_admin())
      {
        add_action('init', array($this, 'registerBlock'));
      }
    }
  }
  
  function enqueueBlockAssets() {
    wp_enqueue_script('myalbum-local-site');
    wp_enqueue_script('myalbum-remote');
  }
  
  function enqueueAdminBlockAssets() {    
    wp_enqueue_style(
		  'myalbum/blocks',
      plugins_url('assets/css/admin-block.css', PLUGINFILE)
    );
  }
  
  function contentEndPoint() {
    $data = [];

    $tokenStatus = get_transient('myalbum-tokenStatus');
    if((int)$tokenStatus===401 || $tokenStatus===false)
    {
      $link = admin_url('options-general.php?page=myalbum');
      $msg = sprintf(__("Almost there! Please <a href='%s'>submit a token</a> for your MyAlbum plugin.", "myalbum"), $link);
      $data['error'] = $msg;
    }else {
      $apiReturn = Api::cache('v1/member/content', 120);
      $content = json_decode($apiReturn['body']);
      $data = [
        'content' => $this->getMemberContent($content)
      ];
    }
    
    return $data;
  }

  function searchEndPoint() {
    if(empty($_GET['search']))
    {
      return $this->contentEndPoint();
    }else 
    {
      $apiReturn = Api::get('v1/member/content/search?query='.urlencode($_GET['search']));
      $content = json_decode($apiReturn['body']);
      $data = $this->getMemberContent($content);
      
      return $data;
    }
  }
  
  // Get content from member (albums, folders etc)
  function getMemberContent($obj)
  {
  	$data = $this->memberContentToSimpleArray($obj->content, $obj->domains);
  	return $data;
  }

  function registerRoutes() {
    register_rest_route(
      'myalbum',
      '/content',
      array(
        'methods'  => 'GET',
        'callback' => array($this, 'contentEndPoint'),
        'permission_callback' => function () {
  				return current_user_can('edit_posts');
  			}
  		)
    );

    register_rest_route(
      'myalbum',
      '/search',
      array(
        'methods'  => 'GET',
        'callback' => array($this, 'searchEndPoint'),
        'permission_callback' => function () {
  				return current_user_can('edit_posts');
  			}
  		)
    );
  }
 
  function registerBlock() {            
    wp_register_script(
      'myalbum-album',
      plugins_url('assets/js/index.js', PLUGINFILE),
      array(
        'wp-i18n',
        'wp-blocks',
        'wp-element',
        'wp-editor',
        'wp-api-fetch',
        'myalbum-remote'
      ),
      filemtime(plugin_dir_path(PLUGINFILE).'assets/js/index.js')
    );

    wp_set_script_translations('myalbum-album', 'myalbum', plugin_dir_path( PLUGINFILE ) . 'languages');
 
    register_block_type('myalbum/album', array(
      'editor_script' => 'myalbum-album',
    ));
  }

  // Converts member content to simple array
	function memberContentToSimpleArray($array, $domains)
	{
  	$simpleArray = array();
  	foreach($array as $nr=>$object):
  	  $headerPhoto = $object->headerPhoto->sizes[0];
  	  $newArr = array(
    	  'type' => $object->type,
    	  'title' => $object->title,
    	  'id' => $object->key,
    	  'headerPhoto' => $domains[$headerPhoto[4]].$headerPhoto[3]
  	  );
  	  
  	  if($object->type=='folder')
  	    unset($newArr['headerPhoto']);
      else if($object->type=='album')
      {
        if(empty($object->user) || !$object->user->isAlbumOwner)
          unset($newArr['key']);
      }
  	  
  	  if($object->content)
    	  $newArr['content'] = $this->memberContentToSimpleArray($object->content, $domains);
  	  
  	  $simpleArray[] = $newArr;
    endforeach;
     	
  	return $simpleArray;
	}
}
?>