<?php
namespace MyAlbum;

  class MediaLibrary
  {
    public function __construct()
    {
      add_filter('media_upload_tabs', array($this, 'createNewTab'));
      add_filter('media_upload_myalbum', array($this, 'mediaUploadMyalbum'));
      add_action('wp_ajax_myalbum_json', array($this, 'renderJSON'));
      
			//add_action('admin_enqueue_scripts', array($this, 'registerScripts')); // Werkt niet in PHP 4.5.3
			$this->registerScripts();
    }
    
    function registerScripts()
    {
      wp_register_script('myalbum-medialibrary', plugins_url('assets/js/medialibrary.js', PLUGINFILE), null, true);
    }
        
    function createNewTab($tabs)
    {
      // Check if API is available with current settings
      if(Api::cache('v1/member', 0, false)['headers']['http_code']==200)
  		  $tabs['myalbum'] = __('Insert from MyAlbum', "myalbum");
  		
  		return $tabs;
  	}
  	
  	// Creates HTML for media browser
  	function mediaUploadMyalbum()
  	{
    	wp_enqueue_style("myalbum-medialibrary", plugins_url('assets/css/medialibrary.css', PLUGINFILE));
    	wp_enqueue_script('myalbum-medialibrary');
    	wp_enqueue_media();
    	wp_localize_script('myalbum-medialibrary', 'ajax_object', array('ajax_url'=>admin_url('admin-ajax.php')));
    	
  		return wp_iframe(array($this, 'mediaTabContent'), 'media');
  	}
  	
  	// Get content from member (albums, folders etc)
  	function getMemberContent($obj)
  	{
    	$data = array(
    	  'content' => $this->memberContentToSimpleArray($obj->content),
    	  'domains' => $obj->domains  
      );
      
    	return $data;
  	}
  	
  	// Converts member content to simple array
  	function memberContentToSimpleArray($array)
  	{
    	$simpleArray = array();
    	foreach($array as $nr=>$object):
    	  $newArr = array(
      	  'type' => $object->type,
      	  'title' => $object->title,
      	  'key' => $object->key,
      	  'headerPhoto' => $object->headerPhoto->sizes[0]
    	  );
    	  
    	  if($object->type=='folder')
    	    unset($newArr['headerPhoto']);
        else if($object->type=='album')
        {
          if(empty($object->user) || !$object->user->isAlbumOwner)
            unset($newArr['key']);
        }
    	  
    	  if($object->content)
      	  $newArr['content'] = $this->memberContentToSimpleArray($object->content);
    	  
    	  $simpleArray[] = $newArr;
    	endforeach;
    	
    	return $simpleArray;
  	}
  	
  	function renderJSON()
  	{
    	$exec = '';
    	if(isset($_REQUEST['exec']))
    	  $exec = $_REQUEST['exec'];
      
      $status = 404;
      $data = array();
    	switch($exec)
    	{
      	case 'album':
      	  if(isset($_REQUEST['key']))
      	  {
      	    $apiReturn = Api::cache('v1/album/'.urlencode($_REQUEST['key']), 120);
      	    $data = json_decode($apiReturn['body']);
      	    $status = $apiReturn['status'];
          }
      	break;
      	
      	case 'search':
      	default:
      	  if(isset($_GET['search']))
        	  $apiReturn = Api::get('v1/member/content/search?query='.urlencode($_GET['search']));
          else
            $apiReturn = Api::cache('v1/member/content', 120);
            
          $content = json_decode($apiReturn['body']);
          $data = $this->getMemberContent($content);
          $status = $apiReturn['status'];
          
          if(count($data['content'])==0)
            $data['msg'] = __("No albums found", "myalbum");
          else
            $data['msg'] = '';
          
      	break;
    	}
    	
    	if($status===200)
    	{
      	wp_send_json_success($data);
      	wp_die();
      }else
      {
        wp_send_json_error($data);
        wp_die();
      }
  	}
  	
  	function mediaTabContent($errors = null)
  	{
      echo '<script type="text/javascript">document.body.className = document.body.className + " myalbum-medialibrary";</script>';
    	echo '<div class="myalbum media-frame">';
    	
      echo '
    	  <div class="topbar"><div class="nav">
    	    <label for="myalbum-nav" class="screen-reader-text">'.__("Navigate MyAlbum", "myalbum").'</label>
    	    <select id="myalbum-nav" class="attachment-filters"><option>MyAlbum</option></select>
    	    </div>
    	    <div class="search-form">
    	      <label for="myalbum-search-input" class="screen-reader-text">'.__('Search MyAlbum...', "myalbum").'</label>
    	      <input type="search" placeholder="'.__('Search MyAlbum...', "myalbum").'" id="myalbum-search-input" class="search">
          </div>
        </div>';
        
      	echo '<ul class="content" id="myalbumContent"></ul>';        
        echo '<div class="bottombar">';
          echo "<form method='post' id='myalbumForm'><input type='hidden' name='send' value='1'><input type='hidden' name='myalbumKey' id='myalbumKey' value=''>";
        	submit_button( __('Insert into page'), 'primary', null, null, array('disabled'=>'1', 'id'=>'myalbumSubmitBtn'));
        	echo "</form>";
        echo '</div>';
        
        echo '<div class="spinner is-active" id="myalbum-spinner"></div>';
        
    	echo '</div>';
  	}
  }